from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Data
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.UI.Xaml.Interop
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class Binding(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Data.BindingBase
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBinding
    _classid_ = 'Microsoft.UI.Xaml.Data.Binding'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.Binding.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IBindingFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.Binding: ...
    @winrt_mixinmethod
    def get_Path(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.PropertyPath: ...
    @winrt_mixinmethod
    def put_Path(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.PropertyPath) -> Void: ...
    @winrt_mixinmethod
    def get_Mode(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.Data.BindingMode: ...
    @winrt_mixinmethod
    def put_Mode(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.Data.BindingMode) -> Void: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_RelativeSource(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.Data.RelativeSource: ...
    @winrt_mixinmethod
    def put_RelativeSource(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.Data.RelativeSource) -> Void: ...
    @winrt_mixinmethod
    def get_ElementName(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ElementName(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Converter(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.Data.IValueConverter: ...
    @winrt_mixinmethod
    def put_Converter(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.Data.IValueConverter) -> Void: ...
    @winrt_mixinmethod
    def get_ConverterParameter(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_ConverterParameter(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ConverterLanguage(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ConverterLanguage(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FallbackValue(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_FallbackValue(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_TargetNullValue(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_TargetNullValue(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_UpdateSourceTrigger(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.Data.UpdateSourceTrigger: ...
    @winrt_mixinmethod
    def put_UpdateSourceTrigger(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.Data.UpdateSourceTrigger) -> Void: ...
    Converter = property(get_Converter, put_Converter)
    ConverterLanguage = property(get_ConverterLanguage, put_ConverterLanguage)
    ConverterParameter = property(get_ConverterParameter, put_ConverterParameter)
    ElementName = property(get_ElementName, put_ElementName)
    FallbackValue = property(get_FallbackValue, put_FallbackValue)
    Mode = property(get_Mode, put_Mode)
    Path = property(get_Path, put_Path)
    RelativeSource = property(get_RelativeSource, put_RelativeSource)
    Source = property(get_Source, put_Source)
    TargetNullValue = property(get_TargetNullValue, put_TargetNullValue)
    UpdateSourceTrigger = property(get_UpdateSourceTrigger, put_UpdateSourceTrigger)
class BindingBase(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBindingBase
    _classid_ = 'Microsoft.UI.Xaml.Data.BindingBase'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.BindingBase.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IBindingBaseFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.BindingBase: ...
class BindingExpression(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Data.BindingExpressionBase
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBindingExpression
    _classid_ = 'Microsoft.UI.Xaml.Data.BindingExpression'
    @winrt_mixinmethod
    def get_DataItem(self: win32more.Microsoft.UI.Xaml.Data.IBindingExpression) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_ParentBinding(self: win32more.Microsoft.UI.Xaml.Data.IBindingExpression) -> win32more.Microsoft.UI.Xaml.Data.Binding: ...
    @winrt_mixinmethod
    def UpdateSource(self: win32more.Microsoft.UI.Xaml.Data.IBindingExpression) -> Void: ...
    DataItem = property(get_DataItem, None)
    ParentBinding = property(get_ParentBinding, None)
class BindingExpressionBase(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBindingExpressionBase
    _classid_ = 'Microsoft.UI.Xaml.Data.BindingExpressionBase'
class BindingMode(Enum, Int32):
    OneWay = 1
    OneTime = 2
    TwoWay = 3
class BindingOperations(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBindingOperations
    _classid_ = 'Microsoft.UI.Xaml.Data.BindingOperations'
    @winrt_classmethod
    def SetBinding(cls: win32more.Microsoft.UI.Xaml.Data.IBindingOperationsStatics, target: win32more.Microsoft.UI.Xaml.DependencyObject, dp: win32more.Microsoft.UI.Xaml.DependencyProperty, binding: win32more.Microsoft.UI.Xaml.Data.BindingBase) -> Void: ...
class _CollectionViewSource_Meta_(ComPtr.__class__):
    pass
class CollectionViewSource(ComPtr, metaclass=_CollectionViewSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource
    _classid_ = 'Microsoft.UI.Xaml.Data.CollectionViewSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.CollectionViewSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Data.CollectionViewSource: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_View(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource) -> win32more.Microsoft.UI.Xaml.Data.ICollectionView: ...
    @winrt_mixinmethod
    def get_IsSourceGrouped(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSourceGrouped(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsPath(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource) -> win32more.Microsoft.UI.Xaml.PropertyPath: ...
    @winrt_mixinmethod
    def put_ItemsPath(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource, value: win32more.Microsoft.UI.Xaml.PropertyPath) -> Void: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ViewProperty(cls: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSourceGroupedProperty(cls: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsPathProperty(cls: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsSourceGrouped = property(get_IsSourceGrouped, put_IsSourceGrouped)
    ItemsPath = property(get_ItemsPath, put_ItemsPath)
    Source = property(get_Source, put_Source)
    View = property(get_View, None)
    _CollectionViewSource_Meta_.IsSourceGroupedProperty = property(get_IsSourceGroupedProperty, None)
    _CollectionViewSource_Meta_.ItemsPathProperty = property(get_ItemsPathProperty, None)
    _CollectionViewSource_Meta_.SourceProperty = property(get_SourceProperty, None)
    _CollectionViewSource_Meta_.ViewProperty = property(get_ViewProperty, None)
class CurrentChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Data.CurrentChangingEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs.CreateInstance(*args, None, None))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs.CreateWithCancelableParameter(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgsFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs: ...
    @winrt_factorymethod
    def CreateWithCancelableParameter(cls: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgsFactory, isCancelable: Boolean, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsCancelable(self: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs) -> Boolean: ...
    Cancel = property(get_Cancel, put_Cancel)
    IsCancelable = property(get_IsCancelable, None)
class CurrentChangingEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3d2a98dd-95b3-5fd5-93b4-a1a2599f225c}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs) -> Void: ...
class DataErrorsChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgsFactory, name: WinRT_String) -> win32more.Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs: ...
    @winrt_mixinmethod
    def get_PropertyName(self: win32more.Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PropertyName(self: win32more.Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgs, value: WinRT_String) -> Void: ...
    PropertyName = property(get_PropertyName, put_PropertyName)
class IBinding(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBinding'
    _iid_ = Guid('{501ea0e8-edd4-59de-8845-76af2eabbe00}')
    @winrt_commethod(6)
    def get_Path(self) -> win32more.Microsoft.UI.Xaml.PropertyPath: ...
    @winrt_commethod(7)
    def put_Path(self, value: win32more.Microsoft.UI.Xaml.PropertyPath) -> Void: ...
    @winrt_commethod(8)
    def get_Mode(self) -> win32more.Microsoft.UI.Xaml.Data.BindingMode: ...
    @winrt_commethod(9)
    def put_Mode(self, value: win32more.Microsoft.UI.Xaml.Data.BindingMode) -> Void: ...
    @winrt_commethod(10)
    def get_Source(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(11)
    def put_Source(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_RelativeSource(self) -> win32more.Microsoft.UI.Xaml.Data.RelativeSource: ...
    @winrt_commethod(13)
    def put_RelativeSource(self, value: win32more.Microsoft.UI.Xaml.Data.RelativeSource) -> Void: ...
    @winrt_commethod(14)
    def get_ElementName(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_ElementName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_Converter(self) -> win32more.Microsoft.UI.Xaml.Data.IValueConverter: ...
    @winrt_commethod(17)
    def put_Converter(self, value: win32more.Microsoft.UI.Xaml.Data.IValueConverter) -> Void: ...
    @winrt_commethod(18)
    def get_ConverterParameter(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(19)
    def put_ConverterParameter(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(20)
    def get_ConverterLanguage(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_ConverterLanguage(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_FallbackValue(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(23)
    def put_FallbackValue(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(24)
    def get_TargetNullValue(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(25)
    def put_TargetNullValue(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(26)
    def get_UpdateSourceTrigger(self) -> win32more.Microsoft.UI.Xaml.Data.UpdateSourceTrigger: ...
    @winrt_commethod(27)
    def put_UpdateSourceTrigger(self, value: win32more.Microsoft.UI.Xaml.Data.UpdateSourceTrigger) -> Void: ...
    Converter = property(get_Converter, put_Converter)
    ConverterLanguage = property(get_ConverterLanguage, put_ConverterLanguage)
    ConverterParameter = property(get_ConverterParameter, put_ConverterParameter)
    ElementName = property(get_ElementName, put_ElementName)
    FallbackValue = property(get_FallbackValue, put_FallbackValue)
    Mode = property(get_Mode, put_Mode)
    Path = property(get_Path, put_Path)
    RelativeSource = property(get_RelativeSource, put_RelativeSource)
    Source = property(get_Source, put_Source)
    TargetNullValue = property(get_TargetNullValue, put_TargetNullValue)
    UpdateSourceTrigger = property(get_UpdateSourceTrigger, put_UpdateSourceTrigger)
class IBindingBase(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingBase'
    _iid_ = Guid('{91ddd141-5944-50ef-b85e-218e463f7a73}')
class IBindingBaseFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingBaseFactory'
    _iid_ = Guid('{c8a866c5-f6f3-5f7a-9592-d385af48bd8f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.BindingBase: ...
class IBindingExpression(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingExpression'
    _iid_ = Guid('{4c023916-37bc-5b07-bc9d-15c547bd9b26}')
    @winrt_commethod(6)
    def get_DataItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_ParentBinding(self) -> win32more.Microsoft.UI.Xaml.Data.Binding: ...
    @winrt_commethod(8)
    def UpdateSource(self) -> Void: ...
    DataItem = property(get_DataItem, None)
    ParentBinding = property(get_ParentBinding, None)
class IBindingExpressionBase(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingExpressionBase'
    _iid_ = Guid('{8825e5a9-d9a3-5e87-bcd8-c63133d29029}')
class IBindingExpressionBaseFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingExpressionBaseFactory'
    _iid_ = Guid('{41d643b9-2629-5451-a716-596c0848b5dc}')
class IBindingExpressionFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingExpressionFactory'
    _iid_ = Guid('{086cae14-81a1-588b-b619-05ee84c0f089}')
class IBindingFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingFactory'
    _iid_ = Guid('{cb2de749-b115-5f67-b64a-797d54885d5c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.Binding: ...
class IBindingOperations(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingOperations'
    _iid_ = Guid('{9a319b95-aabe-5075-b227-8eb07e443d8b}')
class IBindingOperationsStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingOperationsStatics'
    _iid_ = Guid('{1e1bdbd3-fca5-5c85-b87d-b504cd8fa8ac}')
    @winrt_commethod(6)
    def SetBinding(self, target: win32more.Microsoft.UI.Xaml.DependencyObject, dp: win32more.Microsoft.UI.Xaml.DependencyProperty, binding: win32more.Microsoft.UI.Xaml.Data.BindingBase) -> Void: ...
class ICollectionView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.Win32.System.WinRT.IInspectable]]
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionView'
    _iid_ = Guid('{f8bb90d8-e008-5d65-8c97-7bb790a4230c}')
    @winrt_commethod(6)
    def get_CurrentItem(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_CurrentPosition(self) -> Int32: ...
    @winrt_commethod(8)
    def get_IsCurrentAfterLast(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsCurrentBeforeFirst(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_CollectionGroups(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(11)
    def get_HasMoreItems(self) -> Boolean: ...
    @winrt_commethod(12)
    def add_CurrentChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_CurrentChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_CurrentChanging(self, handler: win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_CurrentChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def MoveCurrentTo(self, item: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
    @winrt_commethod(17)
    def MoveCurrentToPosition(self, index: Int32) -> Boolean: ...
    @winrt_commethod(18)
    def MoveCurrentToFirst(self) -> Boolean: ...
    @winrt_commethod(19)
    def MoveCurrentToLast(self) -> Boolean: ...
    @winrt_commethod(20)
    def MoveCurrentToNext(self) -> Boolean: ...
    @winrt_commethod(21)
    def MoveCurrentToPrevious(self) -> Boolean: ...
    @winrt_commethod(22)
    def LoadMoreItemsAsync(self, count: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Data.LoadMoreItemsResult]: ...
    CollectionGroups = property(get_CollectionGroups, None)
    CurrentItem = property(get_CurrentItem, None)
    CurrentPosition = property(get_CurrentPosition, None)
    HasMoreItems = property(get_HasMoreItems, None)
    IsCurrentAfterLast = property(get_IsCurrentAfterLast, None)
    IsCurrentBeforeFirst = property(get_IsCurrentBeforeFirst, None)
    CurrentChanged = event()
    CurrentChanging = event()
class ICollectionViewFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionViewFactory'
    _iid_ = Guid('{d971f795-5728-5bef-9602-43f2c4250e56}')
    @winrt_commethod(6)
    def CreateView(self) -> win32more.Microsoft.UI.Xaml.Data.ICollectionView: ...
class ICollectionViewGroup(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionViewGroup'
    _iid_ = Guid('{96a08da8-be38-5ae0-903d-6fb6111e61f5}')
    @winrt_commethod(6)
    def get_Group(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_GroupItems(self) -> win32more.Windows.Foundation.Collections.IObservableVector[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    Group = property(get_Group, None)
    GroupItems = property(get_GroupItems, None)
class ICollectionViewSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionViewSource'
    _iid_ = Guid('{a45e3b3a-f31e-5bbb-8a7c-70cf5c64bc3f}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_Source(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_View(self) -> win32more.Microsoft.UI.Xaml.Data.ICollectionView: ...
    @winrt_commethod(9)
    def get_IsSourceGrouped(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsSourceGrouped(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_ItemsPath(self) -> win32more.Microsoft.UI.Xaml.PropertyPath: ...
    @winrt_commethod(12)
    def put_ItemsPath(self, value: win32more.Microsoft.UI.Xaml.PropertyPath) -> Void: ...
    IsSourceGrouped = property(get_IsSourceGrouped, put_IsSourceGrouped)
    ItemsPath = property(get_ItemsPath, put_ItemsPath)
    Source = property(get_Source, put_Source)
    View = property(get_View, None)
class ICollectionViewSourceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics'
    _iid_ = Guid('{e282f10f-d4b1-5769-8a11-30f739e6113b}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsSourceGroupedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ItemsPathProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsSourceGroupedProperty = property(get_IsSourceGroupedProperty, None)
    ItemsPathProperty = property(get_ItemsPathProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    ViewProperty = property(get_ViewProperty, None)
class ICurrentChangingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs'
    _iid_ = Guid('{63e42ed6-e14a-51ea-9cb1-72f9c907dc80}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsCancelable(self) -> Boolean: ...
    Cancel = property(get_Cancel, put_Cancel)
    IsCancelable = property(get_IsCancelable, None)
class ICurrentChangingEventArgsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICurrentChangingEventArgsFactory'
    _iid_ = Guid('{3670f48a-ac2c-5352-8a4b-6b977a08e5f8}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs: ...
    @winrt_commethod(7)
    def CreateWithCancelableParameter(self, isCancelable: Boolean, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs: ...
class ICustomProperty(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICustomProperty'
    _iid_ = Guid('{30da92c0-23e8-42a0-ae7c-734a0e5d2782}')
    @winrt_commethod(6)
    def get_Type(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(7)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def GetValue(self, target: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(9)
    def SetValue(self, target: win32more.Windows.Win32.System.WinRT.IInspectable, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(10)
    def GetIndexedValue(self, target: win32more.Windows.Win32.System.WinRT.IInspectable, index: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(11)
    def SetIndexedValue(self, target: win32more.Windows.Win32.System.WinRT.IInspectable, value: win32more.Windows.Win32.System.WinRT.IInspectable, index: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_CanWrite(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_CanRead(self) -> Boolean: ...
    CanRead = property(get_CanRead, None)
    CanWrite = property(get_CanWrite, None)
    Name = property(get_Name, None)
    Type = property(get_Type, None)
class ICustomPropertyProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICustomPropertyProvider'
    _iid_ = Guid('{7c925755-3e48-42b4-8677-76372267033f}')
    @winrt_commethod(6)
    def GetCustomProperty(self, name: WinRT_String) -> win32more.Microsoft.UI.Xaml.Data.ICustomProperty: ...
    @winrt_commethod(7)
    def GetIndexedProperty(self, name: WinRT_String, type: win32more.Windows.UI.Xaml.Interop.TypeName) -> win32more.Microsoft.UI.Xaml.Data.ICustomProperty: ...
    @winrt_commethod(8)
    def GetStringRepresentation(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Type(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    Type = property(get_Type, None)
class IDataErrorsChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgs'
    _iid_ = Guid('{d026dd64-5f26-5f15-a86a-0dec8a431796}')
    @winrt_commethod(6)
    def get_PropertyName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_PropertyName(self, value: WinRT_String) -> Void: ...
    PropertyName = property(get_PropertyName, put_PropertyName)
class IDataErrorsChangedEventArgsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgsFactory'
    _iid_ = Guid('{62d0bd1e-b85f-5fcc-842a-7cb0dda37fe5}')
    @winrt_commethod(6)
    def CreateInstance(self, name: WinRT_String) -> win32more.Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs: ...
class IItemIndexRange(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IItemIndexRange'
    _iid_ = Guid('{eba09846-2554-5b86-ac17-614f05105fa2}')
    @winrt_commethod(6)
    def get_FirstIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Length(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_LastIndex(self) -> Int32: ...
    FirstIndex = property(get_FirstIndex, None)
    LastIndex = property(get_LastIndex, None)
    Length = property(get_Length, None)
class IItemIndexRangeFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IItemIndexRangeFactory'
    _iid_ = Guid('{9fc73213-eda0-5238-aa2c-401c9921f0f9}')
    @winrt_commethod(6)
    def CreateInstance(self, firstIndex: Int32, length: UInt32, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.ItemIndexRange: ...
class IItemsRangeInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Microsoft.UI.Xaml.Data.IItemsRangeInfo'
    _iid_ = Guid('{b8376d08-85fb-563b-8273-39ef2d138256}')
    @winrt_commethod(6)
    def RangesChanged(self, visibleRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange, trackedItems: win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Data.ItemIndexRange]) -> Void: ...
class INotifyDataErrorInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.INotifyDataErrorInfo'
    _iid_ = Guid('{0ee6c2cc-273e-567d-bc0a-1dd87ee51eba}')
    @winrt_commethod(6)
    def get_HasErrors(self) -> Boolean: ...
    @winrt_commethod(7)
    def add_ErrorsChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_ErrorsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def GetErrors(self, propertyName: WinRT_String) -> win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    HasErrors = property(get_HasErrors, None)
    ErrorsChanged = event()
class INotifyPropertyChanged(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.INotifyPropertyChanged'
    _iid_ = Guid('{90b17601-b065-586e-83d9-9adc3a695284}')
    @winrt_commethod(6)
    def add_PropertyChanged(self, handler: win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_PropertyChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    PropertyChanged = event()
class IPropertyChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IPropertyChangedEventArgs'
    _iid_ = Guid('{63d0c952-396b-54f4-af8c-ba8724a427bf}')
    @winrt_commethod(6)
    def get_PropertyName(self) -> WinRT_String: ...
    PropertyName = property(get_PropertyName, None)
class IPropertyChangedEventArgsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IPropertyChangedEventArgsFactory'
    _iid_ = Guid('{7c0c27a8-0b41-5070-b160-fc9ae960a36c}')
    @winrt_commethod(6)
    def CreateInstance(self, name: WinRT_String, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventArgs: ...
class IRelativeSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IRelativeSource'
    _iid_ = Guid('{7ffc8126-5dd8-58bb-b686-c71eddea07b2}')
    @winrt_commethod(6)
    def get_Mode(self) -> win32more.Microsoft.UI.Xaml.Data.RelativeSourceMode: ...
    @winrt_commethod(7)
    def put_Mode(self, value: win32more.Microsoft.UI.Xaml.Data.RelativeSourceMode) -> Void: ...
    Mode = property(get_Mode, put_Mode)
class IRelativeSourceFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IRelativeSourceFactory'
    _iid_ = Guid('{8518522c-85e3-5ae1-b9e9-28ea43c2051e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.RelativeSource: ...
class ISelectionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ISelectionInfo'
    _iid_ = Guid('{1b84c26b-9532-5803-935b-a03bf7e875dc}')
    @winrt_commethod(6)
    def SelectRange(self, itemIndexRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_commethod(7)
    def DeselectRange(self, itemIndexRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_commethod(8)
    def IsSelected(self, index: Int32) -> Boolean: ...
    @winrt_commethod(9)
    def GetSelectedRanges(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Data.ItemIndexRange]: ...
class ISupportIncrementalLoading(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ISupportIncrementalLoading'
    _iid_ = Guid('{d8f9b586-a64a-5ff8-868e-204e144f2cf4}')
    @winrt_commethod(6)
    def LoadMoreItemsAsync(self, count: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Data.LoadMoreItemsResult]: ...
    @winrt_commethod(7)
    def get_HasMoreItems(self) -> Boolean: ...
    HasMoreItems = property(get_HasMoreItems, None)
class IValueConverter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IValueConverter'
    _iid_ = Guid('{afdd2bff-10f5-5173-b7c0-3590bd96cb35}')
    @winrt_commethod(6)
    def Convert(self, value: win32more.Windows.Win32.System.WinRT.IInspectable, targetType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable, language: WinRT_String) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def ConvertBack(self, value: win32more.Windows.Win32.System.WinRT.IInspectable, targetType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: win32more.Windows.Win32.System.WinRT.IInspectable, language: WinRT_String) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
class ItemIndexRange(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IItemIndexRange
    _classid_ = 'Microsoft.UI.Xaml.Data.ItemIndexRange'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.ItemIndexRange.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IItemIndexRangeFactory, firstIndex: Int32, length: UInt32, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.ItemIndexRange: ...
    @winrt_mixinmethod
    def get_FirstIndex(self: win32more.Microsoft.UI.Xaml.Data.IItemIndexRange) -> Int32: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Microsoft.UI.Xaml.Data.IItemIndexRange) -> UInt32: ...
    @winrt_mixinmethod
    def get_LastIndex(self: win32more.Microsoft.UI.Xaml.Data.IItemIndexRange) -> Int32: ...
    FirstIndex = property(get_FirstIndex, None)
    LastIndex = property(get_LastIndex, None)
    Length = property(get_Length, None)
class LoadMoreItemsResult(Structure):
    Count: UInt32
class PropertyChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IPropertyChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Data.PropertyChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventArgs.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IPropertyChangedEventArgsFactory, name: WinRT_String, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventArgs: ...
    @winrt_mixinmethod
    def get_PropertyName(self: win32more.Microsoft.UI.Xaml.Data.IPropertyChangedEventArgs) -> WinRT_String: ...
    PropertyName = property(get_PropertyName, None)
class PropertyChangedEventHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e3de52f6-1e32-5da6-bb2d-b5b6096c962d}')
    @winrt_commethod(3)
    def Invoke(self, sender: win32more.Windows.Win32.System.WinRT.IInspectable, e: win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventArgs) -> Void: ...
class RelativeSource(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Data.IRelativeSource
    _classid_ = 'Microsoft.UI.Xaml.Data.RelativeSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.RelativeSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IRelativeSourceFactory, baseInterface: win32more.Windows.Win32.System.WinRT.IInspectable, innerInterface: POINTER(win32more.Windows.Win32.System.WinRT.IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.RelativeSource: ...
    @winrt_mixinmethod
    def get_Mode(self: win32more.Microsoft.UI.Xaml.Data.IRelativeSource) -> win32more.Microsoft.UI.Xaml.Data.RelativeSourceMode: ...
    @winrt_mixinmethod
    def put_Mode(self: win32more.Microsoft.UI.Xaml.Data.IRelativeSource, value: win32more.Microsoft.UI.Xaml.Data.RelativeSourceMode) -> Void: ...
    Mode = property(get_Mode, put_Mode)
class RelativeSourceMode(Enum, Int32):
    None_ = 0
    TemplatedParent = 1
    Self = 2
class UpdateSourceTrigger(Enum, Int32):
    Default = 0
    PropertyChanged = 1
    Explicit = 2
    LostFocus = 3


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Data.Xml.Dom
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.Printing.PrintTicket
import win32more.Windows.Win32.System.WinRT
class IPrintTicketCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities'
    _iid_ = Guid('{8c45508b-bbdc-4256-a142-2fd615ecb416}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_XmlNamespace(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_XmlNode(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(9)
    def get_DocumentBindingFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(10)
    def get_DocumentCollateFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(11)
    def get_DocumentDuplexFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(12)
    def get_DocumentHolePunchFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(13)
    def get_DocumentInputBinFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(14)
    def get_DocumentNUpFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(15)
    def get_DocumentStapleFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(16)
    def get_JobPasscodeFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(17)
    def get_PageBorderlessFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(18)
    def get_PageMediaSizeFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(19)
    def get_PageMediaTypeFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(20)
    def get_PageOrientationFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(21)
    def get_PageOutputColorFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(22)
    def get_PageOutputQualityFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(23)
    def get_PageResolutionFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(24)
    def GetFeature(self, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(25)
    def GetParameterDefinition(self, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterDefinition: ...
    DocumentBindingFeature = property(get_DocumentBindingFeature, None)
    DocumentCollateFeature = property(get_DocumentCollateFeature, None)
    DocumentDuplexFeature = property(get_DocumentDuplexFeature, None)
    DocumentHolePunchFeature = property(get_DocumentHolePunchFeature, None)
    DocumentInputBinFeature = property(get_DocumentInputBinFeature, None)
    DocumentNUpFeature = property(get_DocumentNUpFeature, None)
    DocumentStapleFeature = property(get_DocumentStapleFeature, None)
    JobPasscodeFeature = property(get_JobPasscodeFeature, None)
    Name = property(get_Name, None)
    PageBorderlessFeature = property(get_PageBorderlessFeature, None)
    PageMediaSizeFeature = property(get_PageMediaSizeFeature, None)
    PageMediaTypeFeature = property(get_PageMediaTypeFeature, None)
    PageOrientationFeature = property(get_PageOrientationFeature, None)
    PageOutputColorFeature = property(get_PageOutputColorFeature, None)
    PageOutputQualityFeature = property(get_PageOutputQualityFeature, None)
    PageResolutionFeature = property(get_PageResolutionFeature, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class IPrintTicketFeature(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature'
    _iid_ = Guid('{e7607d6a-59f5-4103-8858-b97710963d39}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_XmlNamespace(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_XmlNode(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(9)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def GetOption(self, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketOption: ...
    @winrt_commethod(11)
    def get_Options(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketOption]: ...
    @winrt_commethod(12)
    def GetSelectedOption(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketOption: ...
    @winrt_commethod(13)
    def SetSelectedOption(self, value: win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketOption) -> Void: ...
    @winrt_commethod(14)
    def get_SelectionType(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeatureSelectionType: ...
    DisplayName = property(get_DisplayName, None)
    Name = property(get_Name, None)
    Options = property(get_Options, None)
    SelectionType = property(get_SelectionType, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class IPrintTicketOption(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.IPrintTicketOption'
    _iid_ = Guid('{b086cf90-b367-4e4b-bd48-9c78a0bb31ce}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_XmlNamespace(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_XmlNode(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(9)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def GetPropertyNode(self, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(11)
    def GetScoredPropertyNode(self, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(12)
    def GetPropertyValue(self, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValue: ...
    @winrt_commethod(13)
    def GetScoredPropertyValue(self, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValue: ...
    DisplayName = property(get_DisplayName, None)
    Name = property(get_Name, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class IPrintTicketParameterDefinition(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterDefinition'
    _iid_ = Guid('{d6bab4e4-2962-4c01-b7f3-9a9294eb8335}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_XmlNamespace(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_XmlNode(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(9)
    def get_DataType(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterDataType: ...
    @winrt_commethod(10)
    def get_UnitType(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_RangeMin(self) -> Int32: ...
    @winrt_commethod(12)
    def get_RangeMax(self) -> Int32: ...
    DataType = property(get_DataType, None)
    Name = property(get_Name, None)
    RangeMax = property(get_RangeMax, None)
    RangeMin = property(get_RangeMin, None)
    UnitType = property(get_UnitType, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class IPrintTicketParameterInitializer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterInitializer'
    _iid_ = Guid('{5e3335bb-a0a5-48b1-9d5c-07116ddc597a}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_XmlNamespace(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_XmlNode(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(9)
    def put_Value(self, value: win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValue) -> Void: ...
    @winrt_commethod(10)
    def get_Value(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValue: ...
    Name = property(get_Name, None)
    Value = property(get_Value, put_Value)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class IPrintTicketValue(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.IPrintTicketValue'
    _iid_ = Guid('{66b30a32-244d-4e22-a98b-bb3cf1f2dd91}')
    @winrt_commethod(6)
    def get_Type(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValueType: ...
    @winrt_commethod(7)
    def GetValueAsInteger(self) -> Int32: ...
    @winrt_commethod(8)
    def GetValueAsString(self) -> WinRT_String: ...
    Type = property(get_Type, None)
class IWorkflowPrintTicket(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket'
    _iid_ = Guid('{41d52285-35e8-448e-a8c5-e4b6a2cf826c}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_XmlNamespace(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_XmlNode(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(9)
    def GetCapabilities(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketCapabilities: ...
    @winrt_commethod(10)
    def get_DocumentBindingFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(11)
    def get_DocumentCollateFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(12)
    def get_DocumentDuplexFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(13)
    def get_DocumentHolePunchFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(14)
    def get_DocumentInputBinFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(15)
    def get_DocumentNUpFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(16)
    def get_DocumentStapleFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(17)
    def get_JobPasscodeFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(18)
    def get_PageBorderlessFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(19)
    def get_PageMediaSizeFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(20)
    def get_PageMediaTypeFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(21)
    def get_PageOrientationFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(22)
    def get_PageOutputColorFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(23)
    def get_PageOutputQualityFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(24)
    def get_PageResolutionFeature(self) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(25)
    def GetFeature(self, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_commethod(26)
    def NotifyXmlChangedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(27)
    def ValidateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicketValidationResult]: ...
    @winrt_commethod(28)
    def GetParameterInitializer(self, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterInitializer: ...
    @winrt_commethod(29)
    def SetParameterInitializerAsInteger(self, name: WinRT_String, xmlNamespace: WinRT_String, integerValue: Int32) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterInitializer: ...
    @winrt_commethod(30)
    def SetParameterInitializerAsString(self, name: WinRT_String, xmlNamespace: WinRT_String, stringValue: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterInitializer: ...
    @winrt_commethod(31)
    def MergeAndValidateTicket(self, deltaShemaTicket: win32more.Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket: ...
    DocumentBindingFeature = property(get_DocumentBindingFeature, None)
    DocumentCollateFeature = property(get_DocumentCollateFeature, None)
    DocumentDuplexFeature = property(get_DocumentDuplexFeature, None)
    DocumentHolePunchFeature = property(get_DocumentHolePunchFeature, None)
    DocumentInputBinFeature = property(get_DocumentInputBinFeature, None)
    DocumentNUpFeature = property(get_DocumentNUpFeature, None)
    DocumentStapleFeature = property(get_DocumentStapleFeature, None)
    JobPasscodeFeature = property(get_JobPasscodeFeature, None)
    Name = property(get_Name, None)
    PageBorderlessFeature = property(get_PageBorderlessFeature, None)
    PageMediaSizeFeature = property(get_PageMediaSizeFeature, None)
    PageMediaTypeFeature = property(get_PageMediaTypeFeature, None)
    PageOrientationFeature = property(get_PageOrientationFeature, None)
    PageOutputColorFeature = property(get_PageOutputColorFeature, None)
    PageOutputQualityFeature = property(get_PageOutputQualityFeature, None)
    PageResolutionFeature = property(get_PageResolutionFeature, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class IWorkflowPrintTicketValidationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicketValidationResult'
    _iid_ = Guid('{0ad1f392-da7b-4a36-bf36-6a99a62e2059}')
    @winrt_commethod(6)
    def get_Validated(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Validated = property(get_Validated, None)
class PrintTicketCapabilities(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.PrintTicketCapabilities'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNamespace(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNode(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_DocumentBindingFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentCollateFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentDuplexFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentHolePunchFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentInputBinFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentNUpFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentStapleFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_JobPasscodeFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageBorderlessFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageMediaSizeFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageMediaTypeFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageOrientationFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageOutputColorFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageOutputQualityFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageResolutionFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def GetFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def GetParameterDefinition(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketCapabilities, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterDefinition: ...
    DocumentBindingFeature = property(get_DocumentBindingFeature, None)
    DocumentCollateFeature = property(get_DocumentCollateFeature, None)
    DocumentDuplexFeature = property(get_DocumentDuplexFeature, None)
    DocumentHolePunchFeature = property(get_DocumentHolePunchFeature, None)
    DocumentInputBinFeature = property(get_DocumentInputBinFeature, None)
    DocumentNUpFeature = property(get_DocumentNUpFeature, None)
    DocumentStapleFeature = property(get_DocumentStapleFeature, None)
    JobPasscodeFeature = property(get_JobPasscodeFeature, None)
    Name = property(get_Name, None)
    PageBorderlessFeature = property(get_PageBorderlessFeature, None)
    PageMediaSizeFeature = property(get_PageMediaSizeFeature, None)
    PageMediaTypeFeature = property(get_PageMediaTypeFeature, None)
    PageOrientationFeature = property(get_PageOrientationFeature, None)
    PageOutputColorFeature = property(get_PageOutputColorFeature, None)
    PageOutputQualityFeature = property(get_PageOutputQualityFeature, None)
    PageResolutionFeature = property(get_PageResolutionFeature, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class PrintTicketFeature(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.PrintTicketFeature'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNamespace(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNode(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetOption(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketOption: ...
    @winrt_mixinmethod
    def get_Options(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketOption]: ...
    @winrt_mixinmethod
    def GetSelectedOption(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketOption: ...
    @winrt_mixinmethod
    def SetSelectedOption(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature, value: win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketOption) -> Void: ...
    @winrt_mixinmethod
    def get_SelectionType(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketFeature) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeatureSelectionType: ...
    DisplayName = property(get_DisplayName, None)
    Name = property(get_Name, None)
    Options = property(get_Options, None)
    SelectionType = property(get_SelectionType, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class PrintTicketFeatureSelectionType(Enum, Int32):
    PickOne = 0
    PickMany = 1
class PrintTicketOption(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketOption
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.PrintTicketOption'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketOption) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNamespace(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketOption) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNode(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketOption) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketOption) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetPropertyNode(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketOption, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def GetScoredPropertyNode(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketOption, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def GetPropertyValue(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketOption, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValue: ...
    @winrt_mixinmethod
    def GetScoredPropertyValue(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketOption, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValue: ...
    DisplayName = property(get_DisplayName, None)
    Name = property(get_Name, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class PrintTicketParameterDataType(Enum, Int32):
    Integer = 0
    NumericString = 1
    String = 2
class PrintTicketParameterDefinition(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterDefinition
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.PrintTicketParameterDefinition'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterDefinition) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNamespace(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterDefinition) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNode(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterDefinition) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_DataType(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterDefinition) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterDataType: ...
    @winrt_mixinmethod
    def get_UnitType(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterDefinition) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_RangeMin(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterDefinition) -> Int32: ...
    @winrt_mixinmethod
    def get_RangeMax(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterDefinition) -> Int32: ...
    DataType = property(get_DataType, None)
    Name = property(get_Name, None)
    RangeMax = property(get_RangeMax, None)
    RangeMin = property(get_RangeMin, None)
    UnitType = property(get_UnitType, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class PrintTicketParameterInitializer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterInitializer
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.PrintTicketParameterInitializer'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterInitializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNamespace(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterInitializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNode(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterInitializer) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterInitializer, value: win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValue) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketParameterInitializer) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValue: ...
    Name = property(get_Name, None)
    Value = property(get_Value, put_Value)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class PrintTicketValue(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketValue
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.PrintTicketValue'
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketValue) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketValueType: ...
    @winrt_mixinmethod
    def GetValueAsInteger(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketValue) -> Int32: ...
    @winrt_mixinmethod
    def GetValueAsString(self: win32more.Windows.Graphics.Printing.PrintTicket.IPrintTicketValue) -> WinRT_String: ...
    Type = property(get_Type, None)
class PrintTicketValueType(Enum, Int32):
    Integer = 0
    String = 1
    Unknown = 2
class WorkflowPrintTicket(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNamespace(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_XmlNode(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def GetCapabilities(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketCapabilities: ...
    @winrt_mixinmethod
    def get_DocumentBindingFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentCollateFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentDuplexFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentHolePunchFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentInputBinFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentNUpFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_DocumentStapleFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_JobPasscodeFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageBorderlessFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageMediaSizeFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageMediaTypeFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageOrientationFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageOutputColorFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageOutputQualityFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def get_PageResolutionFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def GetFeature(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketFeature: ...
    @winrt_mixinmethod
    def NotifyXmlChangedAsync(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ValidateAsync(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicketValidationResult]: ...
    @winrt_mixinmethod
    def GetParameterInitializer(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket, name: WinRT_String, xmlNamespace: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterInitializer: ...
    @winrt_mixinmethod
    def SetParameterInitializerAsInteger(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket, name: WinRT_String, xmlNamespace: WinRT_String, integerValue: Int32) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterInitializer: ...
    @winrt_mixinmethod
    def SetParameterInitializerAsString(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket, name: WinRT_String, xmlNamespace: WinRT_String, stringValue: WinRT_String) -> win32more.Windows.Graphics.Printing.PrintTicket.PrintTicketParameterInitializer: ...
    @winrt_mixinmethod
    def MergeAndValidateTicket(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicket, deltaShemaTicket: win32more.Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket) -> win32more.Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicket: ...
    DocumentBindingFeature = property(get_DocumentBindingFeature, None)
    DocumentCollateFeature = property(get_DocumentCollateFeature, None)
    DocumentDuplexFeature = property(get_DocumentDuplexFeature, None)
    DocumentHolePunchFeature = property(get_DocumentHolePunchFeature, None)
    DocumentInputBinFeature = property(get_DocumentInputBinFeature, None)
    DocumentNUpFeature = property(get_DocumentNUpFeature, None)
    DocumentStapleFeature = property(get_DocumentStapleFeature, None)
    JobPasscodeFeature = property(get_JobPasscodeFeature, None)
    Name = property(get_Name, None)
    PageBorderlessFeature = property(get_PageBorderlessFeature, None)
    PageMediaSizeFeature = property(get_PageMediaSizeFeature, None)
    PageMediaTypeFeature = property(get_PageMediaTypeFeature, None)
    PageOrientationFeature = property(get_PageOrientationFeature, None)
    PageOutputColorFeature = property(get_PageOutputColorFeature, None)
    PageOutputQualityFeature = property(get_PageOutputQualityFeature, None)
    PageResolutionFeature = property(get_PageResolutionFeature, None)
    XmlNamespace = property(get_XmlNamespace, None)
    XmlNode = property(get_XmlNode, None)
class WorkflowPrintTicketValidationResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicketValidationResult
    _classid_ = 'Windows.Graphics.Printing.PrintTicket.WorkflowPrintTicketValidationResult'
    @winrt_mixinmethod
    def get_Validated(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicketValidationResult) -> Boolean: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Windows.Graphics.Printing.PrintTicket.IWorkflowPrintTicketValidationResult) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Validated = property(get_Validated, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Holographic
import win32more.Windows.Foundation.Numerics
import win32more.Windows.Perception.Spatial
import win32more.Windows.Win32.System.WinRT
class HolographicKeyboard(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Holographic.IHolographicKeyboard
    _classid_ = 'Windows.ApplicationModel.Holographic.HolographicKeyboard'
    @winrt_mixinmethod
    def SetPlacementOverride(self: win32more.Windows.ApplicationModel.Holographic.IHolographicKeyboard, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, topCenterPosition: win32more.Windows.Foundation.Numerics.Vector3, orientation: win32more.Windows.Foundation.Numerics.Quaternion) -> Void: ...
    @winrt_mixinmethod
    def SetPlacementOverrideWithMaxSize(self: win32more.Windows.ApplicationModel.Holographic.IHolographicKeyboard, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, topCenterPosition: win32more.Windows.Foundation.Numerics.Vector3, orientation: win32more.Windows.Foundation.Numerics.Quaternion, maxSize: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_mixinmethod
    def ResetPlacementOverride(self: win32more.Windows.ApplicationModel.Holographic.IHolographicKeyboard) -> Void: ...
    @winrt_classmethod
    def GetDefault(cls: win32more.Windows.ApplicationModel.Holographic.IHolographicKeyboardStatics) -> win32more.Windows.ApplicationModel.Holographic.HolographicKeyboard: ...
class IHolographicKeyboard(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Holographic.IHolographicKeyboard'
    _iid_ = Guid('{07dd0893-aa21-5e6f-a91b-11b2b3fd7be3}')
    @winrt_commethod(6)
    def SetPlacementOverride(self, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, topCenterPosition: win32more.Windows.Foundation.Numerics.Vector3, orientation: win32more.Windows.Foundation.Numerics.Quaternion) -> Void: ...
    @winrt_commethod(7)
    def SetPlacementOverrideWithMaxSize(self, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, topCenterPosition: win32more.Windows.Foundation.Numerics.Vector3, orientation: win32more.Windows.Foundation.Numerics.Quaternion, maxSize: win32more.Windows.Foundation.Numerics.Vector2) -> Void: ...
    @winrt_commethod(8)
    def ResetPlacementOverride(self) -> Void: ...
class IHolographicKeyboardStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Holographic.IHolographicKeyboardStatics'
    _iid_ = Guid('{b676c624-63d7-58cf-b06b-08baa032a23f}')
    @winrt_commethod(6)
    def GetDefault(self) -> win32more.Windows.ApplicationModel.Holographic.HolographicKeyboard: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Storage.Xps
import win32more.Windows.Win32.Storage.Xps.Printing
import win32more.Windows.Win32.System.Com
ID_DOCUMENTPACKAGETARGET_MSXPS: Guid = Guid('{9cae40a8-ded1-41c9-a9fd-d735ef33aeda}')
ID_DOCUMENTPACKAGETARGET_OPENXPS: Guid = Guid('{0056bb72-8c9c-4612-bd0f-93012a87099d}')
ID_DOCUMENTPACKAGETARGET_OPENXPS_WITH_3D: Guid = Guid('{63dbd720-8b14-4577-b074-7bb11b596d28}')
@winfunctype('XPSPRINT.dll')
def StartXpsPrintJob(printerName: win32more.Windows.Win32.Foundation.PWSTR, jobName: win32more.Windows.Win32.Foundation.PWSTR, outputFileName: win32more.Windows.Win32.Foundation.PWSTR, progressEvent: win32more.Windows.Win32.Foundation.HANDLE, completionEvent: win32more.Windows.Win32.Foundation.HANDLE, printablePagesOn: POINTER(Byte), printablePagesOnCount: UInt32, xpsPrintJob: POINTER(win32more.Windows.Win32.Storage.Xps.Printing.IXpsPrintJob), documentStream: POINTER(win32more.Windows.Win32.Storage.Xps.Printing.IXpsPrintJobStream), printTicketStream: POINTER(win32more.Windows.Win32.Storage.Xps.Printing.IXpsPrintJobStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype('XPSPRINT.dll')
def StartXpsPrintJob1(printerName: win32more.Windows.Win32.Foundation.PWSTR, jobName: win32more.Windows.Win32.Foundation.PWSTR, outputFileName: win32more.Windows.Win32.Foundation.PWSTR, progressEvent: win32more.Windows.Win32.Foundation.HANDLE, completionEvent: win32more.Windows.Win32.Foundation.HANDLE, xpsPrintJob: POINTER(win32more.Windows.Win32.Storage.Xps.Printing.IXpsPrintJob), printContentReceiver: POINTER(win32more.Windows.Win32.Storage.Xps.IXpsOMPackageTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintDocumentPackageStatusEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{ed90c8ad-5c34-4d05-a1ec-0e8a9b3ad7af}')
    @commethod(7)
    def PackageStatusUpdated(self, packageStatus: POINTER(win32more.Windows.Win32.Storage.Xps.Printing.PrintDocumentPackageStatus)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintDocumentPackageTarget(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1b8efec4-3019-4c27-964e-367202156906}')
    @commethod(3)
    def GetPackageTargetTypes(self, targetCount: POINTER(UInt32), targetTypes: POINTER(POINTER(Guid))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetPackageTarget(self, guidTargetType: POINTER(Guid), riid: POINTER(Guid), ppvTarget: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Cancel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintDocumentPackageTarget2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c560298a-535c-48f9-866a-632540660cb4}')
    @commethod(3)
    def GetIsTargetIppPrinter(self, isIppPrinter: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetTargetIppPrintDevice(self, riid: POINTER(Guid), ppvTarget: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintDocumentPackageTargetFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d2959bf7-b31b-4a3d-9600-712eb1335ba4}')
    @commethod(3)
    def CreateDocumentPackageTargetForPrintJob(self, printerName: win32more.Windows.Win32.Foundation.PWSTR, jobName: win32more.Windows.Win32.Foundation.PWSTR, jobOutputStream: win32more.Windows.Win32.System.Com.IStream, jobPrintTicketStream: win32more.Windows.Win32.System.Com.IStream, docPackageTarget: POINTER(win32more.Windows.Win32.Storage.Xps.Printing.IPrintDocumentPackageTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsPrintJob(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5ab89b06-8194-425f-ab3b-d7a96e350161}')
    @commethod(3)
    def Cancel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetJobStatus(self, jobStatus: POINTER(win32more.Windows.Win32.Storage.Xps.Printing.XPS_JOB_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IXpsPrintJobStream(ComPtr):
    extends: win32more.Windows.Win32.System.Com.ISequentialStream
    _iid_ = Guid('{7a77dc5f-45d6-4dff-9307-d8cb846347ca}')
    @commethod(5)
    def Close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
PrintDocumentPackageCompletion = Int32
PrintDocumentPackageCompletion_InProgress: win32more.Windows.Win32.Storage.Xps.Printing.PrintDocumentPackageCompletion = 0
PrintDocumentPackageCompletion_Completed: win32more.Windows.Win32.Storage.Xps.Printing.PrintDocumentPackageCompletion = 1
PrintDocumentPackageCompletion_Canceled: win32more.Windows.Win32.Storage.Xps.Printing.PrintDocumentPackageCompletion = 2
PrintDocumentPackageCompletion_Failed: win32more.Windows.Win32.Storage.Xps.Printing.PrintDocumentPackageCompletion = 3
class PrintDocumentPackageStatus(Structure):
    JobId: UInt32
    CurrentDocument: Int32
    CurrentPage: Int32
    CurrentPageTotal: Int32
    Completion: win32more.Windows.Win32.Storage.Xps.Printing.PrintDocumentPackageCompletion
    PackageStatus: win32more.Windows.Win32.Foundation.HRESULT
PrintDocumentPackageTarget = Guid('{4842669e-9947-46ea-8ba2-d8cce432c2ca}')
PrintDocumentPackageTargetFactory = Guid('{348ef17d-6c81-4982-92b4-ee188a43867a}')
XPS_JOB_COMPLETION = Int32
XPS_JOB_IN_PROGRESS: win32more.Windows.Win32.Storage.Xps.Printing.XPS_JOB_COMPLETION = 0
XPS_JOB_COMPLETED: win32more.Windows.Win32.Storage.Xps.Printing.XPS_JOB_COMPLETION = 1
XPS_JOB_CANCELLED: win32more.Windows.Win32.Storage.Xps.Printing.XPS_JOB_COMPLETION = 2
XPS_JOB_FAILED: win32more.Windows.Win32.Storage.Xps.Printing.XPS_JOB_COMPLETION = 3
class XPS_JOB_STATUS(Structure):
    jobId: UInt32
    currentDocument: Int32
    currentPage: Int32
    currentPageTotal: Int32
    completion: win32more.Windows.Win32.Storage.Xps.Printing.XPS_JOB_COMPLETION
    jobStatus: win32more.Windows.Win32.Foundation.HRESULT


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Calls.Provider
import win32more.Windows.Foundation
import win32more.Windows.Storage
import win32more.Windows.Win32.System.WinRT
class IPhoneCallOrigin(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin'
    _iid_ = Guid('{20613479-0ef9-4454-871c-afb66a14b6a5}')
    @winrt_commethod(6)
    def get_Category(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Category(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_CategoryDescription(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_CategoryDescription(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_Location(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_Location(self, value: WinRT_String) -> Void: ...
    Category = property(get_Category, put_Category)
    CategoryDescription = property(get_CategoryDescription, put_CategoryDescription)
    Location = property(get_Location, put_Location)
class IPhoneCallOrigin2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin2'
    _iid_ = Guid('{04c7e980-9ac2-4768-b536-b68da4957d02}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_DisplayName(self, value: WinRT_String) -> Void: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
class IPhoneCallOrigin3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin3'
    _iid_ = Guid('{49330fb4-d1a7-43a2-aeee-c07b6dbaf068}')
    @winrt_commethod(6)
    def get_DisplayPicture(self) -> win32more.Windows.Storage.StorageFile: ...
    @winrt_commethod(7)
    def put_DisplayPicture(self, value: win32more.Windows.Storage.StorageFile) -> Void: ...
    DisplayPicture = property(get_DisplayPicture, put_DisplayPicture)
class IPhoneCallOriginManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Calls.Provider.IPhoneCallOriginManagerStatics'
    _iid_ = Guid('{ccfc5a0a-9af7-6149-39d0-e076fcce1395}')
    @winrt_commethod(6)
    def get_IsCurrentAppActiveCallOriginApp(self) -> Boolean: ...
    @winrt_commethod(7)
    def ShowPhoneCallOriginSettingsUI(self) -> Void: ...
    @winrt_commethod(8)
    def SetCallOrigin(self, requestId: Guid, callOrigin: win32more.Windows.ApplicationModel.Calls.Provider.PhoneCallOrigin) -> Void: ...
    IsCurrentAppActiveCallOriginApp = property(get_IsCurrentAppActiveCallOriginApp, None)
class IPhoneCallOriginManagerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Calls.Provider.IPhoneCallOriginManagerStatics2'
    _iid_ = Guid('{8bf3ee3f-40f4-4380-8c7c-aea2c9b8dd7a}')
    @winrt_commethod(6)
    def RequestSetAsActiveCallOriginAppAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class IPhoneCallOriginManagerStatics3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Calls.Provider.IPhoneCallOriginManagerStatics3'
    _iid_ = Guid('{2ed69764-a6e3-50f0-b76a-d67cb39bdfde}')
    @winrt_commethod(6)
    def get_IsSupported(self) -> Boolean: ...
    IsSupported = property(get_IsSupported, None)
class PhoneCallOrigin(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin
    _classid_ = 'Windows.ApplicationModel.Calls.Provider.PhoneCallOrigin'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Calls.Provider.PhoneCallOrigin.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Calls.Provider.PhoneCallOrigin: ...
    @winrt_mixinmethod
    def get_Category(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Category(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_CategoryDescription(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CategoryDescription(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Location(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Location(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin2, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayPicture(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin3) -> win32more.Windows.Storage.StorageFile: ...
    @winrt_mixinmethod
    def put_DisplayPicture(self: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOrigin3, value: win32more.Windows.Storage.StorageFile) -> Void: ...
    Category = property(get_Category, put_Category)
    CategoryDescription = property(get_CategoryDescription, put_CategoryDescription)
    DisplayName = property(get_DisplayName, put_DisplayName)
    DisplayPicture = property(get_DisplayPicture, put_DisplayPicture)
    Location = property(get_Location, put_Location)
class _PhoneCallOriginManager_Meta_(ComPtr.__class__):
    pass
class PhoneCallOriginManager(ComPtr, metaclass=_PhoneCallOriginManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Calls.Provider.PhoneCallOriginManager'
    @winrt_classmethod
    def get_IsSupported(cls: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOriginManagerStatics3) -> Boolean: ...
    @winrt_classmethod
    def RequestSetAsActiveCallOriginAppAsync(cls: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOriginManagerStatics2) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def get_IsCurrentAppActiveCallOriginApp(cls: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOriginManagerStatics) -> Boolean: ...
    @winrt_classmethod
    def ShowPhoneCallOriginSettingsUI(cls: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOriginManagerStatics) -> Void: ...
    @winrt_classmethod
    def SetCallOrigin(cls: win32more.Windows.ApplicationModel.Calls.Provider.IPhoneCallOriginManagerStatics, requestId: Guid, callOrigin: win32more.Windows.ApplicationModel.Calls.Provider.PhoneCallOrigin) -> Void: ...
    _PhoneCallOriginManager_Meta_.IsCurrentAppActiveCallOriginApp = property(get_IsCurrentAppActiveCallOriginApp, None)
    _PhoneCallOriginManager_Meta_.IsSupported = property(get_IsSupported, None)


make_ready(__name__)
